March 10, 2016 - Colorado Court of Appeals Opinions

| CBA Home | CLE Home | Contact Us | Cart - empty
Log On My Cobar
| ## Search |
| CBA CLE About Us Membership For Lawyers Representing the Moderate Income Client STRATUM Colorado Mentoring Program COLTAF Casemaker The Colorado Lawyer Opinions/ Rules/ Statutes By Practice Area Practice Management Find A Lawyer Colorado Courts Website Continuing Legal Education Ethics Professionalism Resources Attorney Registration E-Filing Legislative Matters Employment Listserves Law Related Websites Litigators Handbook Join the CBA Confidential Assistance for Attorneys Help - FAQs Young Lawyers Division Inside the Bar News/Media Resources For the Public From the Courts Pro Bono/Volunteer Opportunities Employment/Classified Ads
| Colorado Court of Appeals Opinions March 10, 2016
The Court of Appeals summaries are written for the Colorado Bar Association by licensed attorneys Teresa Wilkins (Denver) and Paul Sachs (Steamboat Springs). Please note that the summaries of Opinions of the Colorado Court of Appeals are provided as a service by the Colorado Bar Association and are not the official language of the Court. The Colorado Bar Association cannot guarantee the accuracy or completeness of the summaries.
2016 COA 32. No. 14CA1424. Brooks v. Raemisch. 2016 COA 33. Nos. 14CA1483 & 15CA0216. Rocky Mountain Exploration, Inc. v. Davis Graham & Stubbs LLP. 2016 COA 34. No. 14CA1581. Estate of Robert A. Petteys v. Farmers State Bank of Brush. 2016 COA 35. No. 14CA1719. People v. Mazzarelli. 2016 COA 36. No. 14CA2192. In re the Marriage of Gross. 2016 COA 37. No. 14CA2383. Department of Human Services, Colorado v. State Personnel Board. 2016 COA 38.Nos. 14CA2454, 14CA2455, 14CA2456 People In the Interest of E.M. and Concerning L.G.M. Nos. 14CA2454, 14CA2455, 14CA2456 & 14CA1457 2016 COA 39. No. 14CA2502. Lindauer v. Williams Production RMT Company. 2016 COA 40. No. 15CA0109. Rowland v. Department of Revenue. 2016 COA 41. No. 15CA0346. Foster v. Plock. Colorado Court of Appeals Opinions Back |